#
# spec file for package rpm2docserv
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if ! %{defined _distconfdir}
%define _distconfdir %{_sysconfdir}
%endif

Name:           rpm2docserv
Version:        20250327.1888603
Release:        1.1
Summary:        Make manpages from RPMs accessible in a web browser
License:        Apache-2.0
URL:            https://github.com/thkukuk/rpm2docserv
Source:         rpm2docserv-%{version}.tar.xz
Source1:        vendor.tar.gz
Source2:        tumbleweed.yaml
Source3:        leap.idx
BuildRequires:  sysuser-shadow
BuildRequires:  sysuser-tools
BuildRequires:  golang(API) >= 1.23
Requires:       /usr/bin/mandoc
Requires:       cpio

%description
rpm2docserv extracts manual pages from RPM packages and makes them accessible in a web browser.

%package -n docserv-auxserver
Summary:        Docserv auxiliary service endpoints
%{sysusers_requires}

%description -n docserv-auxserver
docserv-auxserver has a very efficient, small map to redirect to the correct manual page for rpm2docserv created html repositories.

%package -n docserv-minisrv
Summary:        Simple docserv webserver
%{sysusers_requires}

%description -n docserv-minisrv
Simple docserv webserver with integrated auxserver for development and test purposes. Not for production.

%package -n docserv-sitemap
Summary:        Generate sitemap xml files for rpm2docserv

%description -n docserv-sitemap
This tool generates sitemap xml files from a rpm2docserv generated docserv directory for search engines.

%package -n docserv-config-nginx
Summary:        Configuration files for nginx to serve docserv directory
BuildArch:      noarch

%description -n docserv-config-nginx
This package contains example configuration files for nginx to act as web server for docserv manpages.

%package -n docserv-config-apache2
Summary:        Configuration files for Apache 2.4 to serve docserv directory
BuildArch:      noarch

%description -n docserv-config-apache2
This package contains example configuration files for Apache 2.4 to act as web server for docserv manpages.

%prep
%setup -q -a1

%build
make bundle
%make_build build VERSION=%{version} USE_VENDOR="-mod vendor"

%sysusers_generate_pre systemd/system-user-docserv-aux.conf docserv-aux system-user-docserv-aux.conf
%sysusers_generate_pre systemd/system-user-docserv-srv.conf docserv-srv system-user-docserv-srv.conf

%install
mkdir -p %{buildroot}%{_bindir}
install -m 755 bin/rpm2docserv %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_sbindir}
install -m 755 bin/docserv-auxserver %{buildroot}%{_sbindir}/
install -m 755 bin/docserv-minisrv %{buildroot}%{_sbindir}/
install -m 755 bin/docserv-sitemap %{buildroot}%{_bindir}/
mkdir -p %{buildroot}%{_datadir}/%{name}
cp -r assets %{buildroot}%{_datadir}/%{name}
mkdir -p %{buildroot}%{_datadir}/%{name}/{configs,index}
install -m 0644 %{SOURCE2} %{buildroot}%{_datadir}/%{name}/configs/
install -m 0644 %{SOURCE3} %{buildroot}%{_datadir}/%{name}/index/

install -D -m 0644 systemd/docserv-auxserver.service %{buildroot}%{_unitdir}/docserv-auxserver.service
install -D -m 0644 systemd/docserv-auxserver.default %{buildroot}%{_distconfdir}/default/docserv-auxserver
install -D -m 0644 systemd/docserv-auxserver-reload.path %{buildroot}%{_unitdir}/docserv-auxserver-reload.path
install -D -m 0644 systemd/docserv-auxserver-reload.service %{buildroot}%{_unitdir}/docserv-auxserver-reload.service
install -D -m 0644 systemd/docserv-minisrv.service %{buildroot}%{_unitdir}/docserv-minisrv.service
install -D -m 0644 systemd/docserv-minisrv.default %{buildroot}%{_distconfdir}/default/docserv-minisrv
mkdir -p %{buildroot}%{_sysusersdir}/
install -m 644 systemd/system-user-*.conf %{buildroot}%{_sysusersdir}/

# nginx container
mkdir -p %{buildroot}%{_datadir}/docserv/nginx
install -m 755 nginx/*.sh %{buildroot}%{_datadir}/docserv/nginx/
install -m 644 nginx/*.conf %{buildroot}%{_datadir}/docserv/nginx/

# apache configuration
mkdir -p %{buildroot}%{_datadir}/docserv/apache2
install -m 644 apache2/* %{buildroot}%{_datadir}/docserv/apache2/

%pre -n docserv-auxserver -f docserv-aux.pre
%service_add_pre docserv-auxserver.service docserv-auxserver-reload.path

%post -n docserv-auxserver
%service_add_post docserv-auxserver.service docserv-auxserver-reload.path

%preun -n docserv-auxserver
%service_del_preun docserv-auxserver.service docserv-auxserver-reload.path

%postun -n docserv-auxserver
%service_del_postun docserv-auxserver.service docserv-auxserver-reload.path

%pre -n docserv-minisrv -f docserv-srv.pre
%service_add_pre docserv-minisrv.service

%post -n docserv-minisrv
%service_add_post docserv-minisrv.service

%preun -n docserv-minisrv
%service_del_preun docserv-minisrv.service

%postun -n docserv-minisrv
%service_del_postun docserv-minisrv.service

%files
%license LICENSE
%{_bindir}/rpm2docserv
%{_datadir}/%{name}

%files -n docserv-auxserver
%license LICENSE
%{_sbindir}/docserv-auxserver
%{_unitdir}/docserv-auxserver.service
%{_unitdir}/docserv-auxserver-reload.path
%{_unitdir}/docserv-auxserver-reload.service
%{_sysusersdir}/system-user-docserv-aux.conf
%if 0%{?suse_version} >= 1599
%{_distconfdir}/default/docserv-auxserver
%else
%config %{_distconfdir}/default/docserv-auxserver
%endif

%files -n docserv-minisrv
%license LICENSE
%{_sbindir}/docserv-minisrv
%{_unitdir}/docserv-minisrv.service
%{_sysusersdir}/system-user-docserv-srv.conf
%if 0%{?suse_version} >= 1599
%{_distconfdir}/default/docserv-minisrv
%else
%config %{_distconfdir}/default/docserv-minisrv
%endif

%files -n docserv-sitemap
%license LICENSE
%{_bindir}/docserv-sitemap

%files -n docserv-config-nginx
%dir %{_datadir}/docserv
%{_datadir}/docserv/nginx

%files -n docserv-config-apache2
%dir %{_datadir}/docserv
%{_datadir}/docserv/apache2

%changelog
* Thu Mar 27 2025 kukuk@suse.com
- Update to version 20250327.1888603:
  * Sync config file struct
  * unrpm: make all files read/writable for the user
  * Update go dependencies
  * Don't render products imported via idx file
  * Remove obsolete comments
- Add tumbleweed.yaml and leap.idx
* Tue Mar 25 2025 kukuk@suse.com
- Update to version 20250321.37b55b5:
  * auxserver: use english as default if no language is set
  * Remove debug message
  * Remove broken entries from xref/index
  * Remove debug message
  * Make search for update-alternatives in scripts more robust
  * Merge pkgEntry with PkgMeta
  * Fix total number of pkgs
  * Further optimization of building gv.pkgs
  * Optimize size of pkgs, only store RPMs with manpages
  * Fallback to io.Reader if gz file is not compressed
  * Rename suite -> product
  * Update go dependencies
  * Remove unused process variable overhead for mandoc
  * Remove outdated comment
  * Rewrite to use internal data and not files
  * Remove debug message
  * Suites -> Products rename
  * Unify template.Execute calls/variables
  * Build package directories from internal data
  * Use global productList instead of creating it again and again
  * Rename product Name/URL to project Name/URL
  * Use MicroOS/Tumbleweed as example for Mapping
  * Remove unused and outdated tests
* Wed Mar  5 2025 kukuk@suse.com
- Update to version 20250305.e46df41:
  * index page: list valid product names for search
  * Rename bySuiteStr with byProductStr
  * Update go dependencies
  * rpm2docserv: don't start a webserver
  * sitemap: rename suite to product
  * Start rename "suite" to ProductName and ProductMapping
  * Remove docserv-idx2rwmap, use nginx
  * Allow aliases for product names
  * Remove unused "Replaces"
  * Use "suites" as Product Name and sort correct
  * Fix comment about "suites"
  * Print Product Names and Mapping
  * Add sorted products to index, fix search logic
* Mon Mar  3 2025 kukuk@suse.com
- Update to version 20250303.dcd3fee:
  * notfound.tmpl: fix syntax error
  * Make doxserv-auxserver.service more robust
  * Add help text for search and Leap-*
  * auxserver: fix lang selection, show all possible choices if no match
  * Update go module dependencies
  * Remove autognerated bundle file
  * css style: don't limit manpage to 80 character
* Sat Mar  1 2025 kukuk@suse.com
- Update to version 20250301.91b4735:
  * docserv-miniserv: support multiple index files
  * Update go dependencies
  * dump-auxserver: debugging tool for auxserver.idx
  * docserv-auxserver: print number of sections, too
  * Allow several auxserver index files
* Thu Feb 27 2025 kukuk@suse.com
- Update to version 20250227.6e4073c:
  * auxserver: rework debug messages
  * Change "Tumbleweed" to "Tumbleweed + MicroOS" on index page
  * Remove wrong install section
  * Add service which reloads auxserver if idx changed
  * Replace deprecated ioutil
  * Adjust path for assets
  * Update dependencies
  * Makefile: adjust for deprecated go get options
* Wed Jan  8 2025 kukuk@suse.com
- Update to version 20250107.10e1695:
  * Update dependencies
  * Replace hostname command
  * Add metrics namespace
* Wed Mar 20 2024 kukuk@suse.com
- Update to version 20240320.aa59b30:
  * Switch to google.golang.org/protobuf
* Wed Mar  8 2023 kukuk@suse.com
- Update to version 20230308.4ed55cf:
  * Remove forceRender, don't compress index.html
  * Update dependencies
- Add service to generate vendor.tar.gz
* Thu Jan 19 2023 kukuk@suse.com
- Update to version 20230119.8224a04:
  * Update dependencies
  * Remove "index.html" from URLs
* Fri Dec  2 2022 Thorsten Kukuk <kukuk@suse.com>
- Update vendor dir
* Fri Dec  2 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Require /usr/bin/mandoc: we rely on mandoc to render the man
  pages as html.
* Thu Dec  1 2022 Thorsten Kukuk <kukuk@suse.com>
- Fix building on Leap 15.4
* Thu Dec  1 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add dependency on cpio: rpm2docserv uses cpio to extract RPMs.
* Tue Nov 29 2022 kukuk@suse.com
- Update to version 20221129.a10bb7c:
  * Re-generate bundled data
  * Enhance introduction on start page
  * Quote ld+json string corret as JS, not HTML
* Fri Nov 25 2022 kukuk@suse.com
- Update to version 20221125.c82d2b0:
  * Create sitemap.xml for root directory, too
* Fri Nov 25 2022 kukuk@suse.com
- Update to version 20221125.be8d83b:
  * Split sitemap.xml into chunks, use yaml config
* Mon Nov 21 2022 kukuk@suse.com
- Update to version 20221121.c1d43dd:
  * Update dependencies
  * Add docserv-sitemap to generate sitemap xml files
  * Use docserv instead of debiman for temporary files
* Tue Nov  8 2022 kukuk@suse.com
- Update to version 20221108.e2b9545:
  * Replace documentation with manpages
  * Create issues from TODO list
  * Generate profile data
  * Add about.html content
* Tue Oct 25 2022 kukuk@suse.com
- Update to version 20221025.f562697:
  * Use absolut URL for logo
* Mon Oct 24 2022 kukuk@suse.com
- Update to version 20221024.57b37b8:
  * Update dependencies
  * Use MicroOS logo, switch to offline build
  * Fix usage of external style sheet (#2)
  * Add "IsOffline" variable for templates
* Mon Oct 17 2022 kukuk@suse.com
- Update to version 20221017.6bcf1b6:
  * Add MicroOS logo as overlay for chameleon style
  * Support "assets" in yaml config
- Package assets directory
* Thu Oct 13 2022 kukuk@suse.com
- Update to version 20221013.faaac97:
  * Update go dependencies
  * Add tumbleweed logo
  * Add local version of logo
  * Add empty .Suites to avoid build errors in auxserver
  * Store svg files, too
  * Add comment about rework of 404 error handling
  * Use local stored logo
  * Use product logo in header
  * Replace "manpages" with "product" in URL description
  * Rename fallback-icon with breadcrumb-icon
  * Print stderr with cpio error code
  * Don't remap existing, uncompressed files
  * Rename "-inject-assets" to "-assets"
  * Add stderr of cpio to error message
* Fri Oct  7 2022 kukuk@suse.com
- Update to version 20221007.388ef0d:
  * Fix filenames in bundle
  * Update dependencies
* Fri Oct  7 2022 kukuk@suse.com
- Update to version 20221007.2bb8b40:
  * Move template in own sub-directory
  * Use chameleon css for theming (#1)
  * "other versions" box uses now "AltVersions" instead of "Suites"
  * Make .Suites variable available everywhere to be useable in header.tmpl
  * Enhance package list for microos.yaml
* Wed Sep 21 2022 kukuk@suse.com
- Update to version 20220921.1b436b1:
  * Add config for apache RewriteMap
  * Add more documentation
  * Add rewrite rules
  * Create container using MicroOS config
  * Add self signed certificate
  * Add example config for Tumbleweed
  * Add apache2 configs
  * Add tool to create apache rewrite map
  * Fix cleanup of bin directory
* Thu Sep  8 2022 kukuk@suse.com
- Update to version 20220908.b6c57bc:
  * Fix GENERATED_bundled.go
* Thu Sep  8 2022 kukuk@suse.com
- Update to version 20220908.043e053:
  * Make the templates more configureable (e.g. Tumbleweed vs MicroOS)
  * Cleanup TODO list
  * Use rpm version struct, sort according suite/binarypkg/version
  * Sort package list to have higher versions first
* Thu Sep  8 2022 kukuk@suse.com
- Update to version 20220908.347af2c:
  * Disable dhparam.pem generation, slowdowns start of container too much
* Thu Sep  8 2022 kukuk@suse.com
- Update to version 20220908.919f918:
  * Update go.mod and go.sum
* Thu Sep  8 2022 kukuk@suse.com
- Update to version 20220908.24fb5ea:
  * Provide https support with self signed certificates
  * Support multiple products and multiple caches per product
  * Adjust docu
* Tue Sep  6 2022 kukuk@suse.com
- Update to version 20220906.ca795b9:
  * Fix wrong error check
* Tue Sep  6 2022 kukuk@suse.com
- Update to version 20220906.3bbe357:
  * Read informations from RPM if we cannot split RPM name
  * Add script to build container with correct args
* Tue Sep  6 2022 kukuk@suse.com
- Update to version 20220906.2b1b6c3:
  * Fix some typos and grant capability to get network port
* Tue Sep  6 2022 kukuk@suse.com
- Update to version 20220906.16db3f7:
  * Add sysusers templates for systemd services
* Tue Sep  6 2022 Thorsten Kukuk <kukuk@suse.com>
- Create docserv-config-nginx
* Tue Sep  6 2022 kukuk@suse.com
- Update to version 20220906.54b1d83:
  * Regenerate bundled templates
* Mon Sep  5 2022 kukuk@suse.com
- Update to version 20220905.e06bf4f:
  * Fist CSS changes from Alexandre Vicenzi
  * Separate manpages by binary and source package in index
* Fri Sep  2 2022 kukuk@suse.com
- Update to version 20220902.ec7c5b0:
  * Add systemd service files
* Thu Sep  1 2022 kukuk@suse.com
- Update to version 20220901.e5c886b:
  * Update TODO List
  * Correct check of return value of getUpdateAlternatives
  * Relax in a second search round strict Section match
  * Follow symlinks alredy when unpacking RPMs, code optimization
  * Try to find missing manpages with xref index
  * Make sure binary search does not go outside range
  * Handle .gz in .so references
  * Update Makefile and go.* files
  * Rewrite unpacking and renaming of manpages
  * Store full source rpm name, too
